@@ -5,8 +5,6 @@ __author__ = 'Alberto Martín Mateos and Niloufar Shoeibi'
 __version__ = '0.0.1'
 
 from .api import load_file
-from .api import duplicates_detection
-from .api import close_duplicates
 from .api import merge_dataframes
 from .api import profile_connections
 from .api import building_node_list
@@ -29,4 +27,8 @@ from .api import profile_trend_visualization
 from .api import text_to_list_features_conversor
 from .api import profile_max_tw_day_hourly_visualization
 from .api import terrorist_tweets_classification_pieChart
-from .api import distribution_sentiment_terrorist_tweets
\ No newline at end of file
+from .api import distribution_sentiment_terrorist_tweets
+from .api import close_duplicates
+from .api import duplicates_detection
+from .api import community_algortihm
+from .api import graph_json_values
\ No newline at end of file
