@@ -253,7 +253,7 @@ def graph_features(DiG,df):
     output = merge_dataframes(output, df_nodes_self_loop_iteration)
     return output
     
-def graph_json_values(df_graph, df_algoComu):
+def graph_json_values(df_graph, df_algComu):
     
     data = {}
     data['nodes'] = []
